@@ -50,10 +50,10 @@
 /* VOID:UINT,UINT,UINT,STRING (mission-control-signals-marshal.list:1) */
 void
 mission_control_signals_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closure,
-                                                             GValue       *return_value,
+                                                             GValue       *return_value G_GNUC_UNUSED,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
-                                                             gpointer      invocation_hint,
+                                                             gpointer      invocation_hint G_GNUC_UNUSED,
                                                              gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT_UINT_STRING) (gpointer     data1,
@@ -91,10 +91,10 @@ mission_control_signals_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closu
 /* VOID:STRING,UINT (mission-control-signals-marshal.list:2) */
 void
 mission_control_signals_marshal_VOID__STRING_UINT (GClosure     *closure,
-                                                   GValue       *return_value,
+                                                   GValue       *return_value G_GNUC_UNUSED,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
-                                                   gpointer      invocation_hint,
+                                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                                    gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_UINT) (gpointer     data1,
@@ -128,10 +128,10 @@ mission_control_signals_marshal_VOID__STRING_UINT (GClosure     *closure,
 /* VOID:UINT,UINT (mission-control-signals-marshal.list:3) */
 void
 mission_control_signals_marshal_VOID__UINT_UINT (GClosure     *closure,
-                                                 GValue       *return_value,
+                                                 GValue       *return_value G_GNUC_UNUSED,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
-                                                 gpointer      invocation_hint,
+                                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
@@ -165,10 +165,10 @@ mission_control_signals_marshal_VOID__UINT_UINT (GClosure     *closure,
 /* VOID:UINT,STRING,UINT (mission-control-signals-marshal.list:4) */
 void
 mission_control_signals_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
-                                                        GValue       *return_value,
+                                                        GValue       *return_value G_GNUC_UNUSED,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
-                                                        gpointer      invocation_hint,
+                                                        gpointer      invocation_hint G_GNUC_UNUSED,
                                                         gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_STRING_UINT) (gpointer     data1,
@@ -206,10 +206,10 @@ mission_control_signals_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
 /* VOID:UINT,UINT,STRING,UINT,STRING (mission-control-signals-marshal.list:6) */
 void
 mission_control_signals_marshal_VOID__UINT_UINT_STRING_UINT_STRING (GClosure     *closure,
-                                                                    GValue       *return_value,
+                                                                    GValue       *return_value G_GNUC_UNUSED,
                                                                     guint         n_param_values,
                                                                     const GValue *param_values,
-                                                                    gpointer      invocation_hint,
+                                                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT_STRING_UINT_STRING) (gpointer     data1,
@@ -249,10 +249,10 @@ mission_control_signals_marshal_VOID__UINT_UINT_STRING_UINT_STRING (GClosure
 /* VOID:UINT,STRING (mission-control-signals-marshal.list:7) */
 void
 mission_control_signals_marshal_VOID__UINT_STRING (GClosure     *closure,
-                                                   GValue       *return_value,
+                                                   GValue       *return_value G_GNUC_UNUSED,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
-                                                   gpointer      invocation_hint,
+                                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                                    gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_STRING) (gpointer     data1,
