@@ -1214,6 +1214,11 @@ on_connection_status_changed (TpConnection *tp_conn, GParamSpec *pspec,
 	break;
     case TP_CONNECTION_STATUS_CONNECTED:
 	{
+#ifndef MC_MAEMO_BUILD
+	    /* We successfully connected the account, make sure we don't retry
+	     * to register it next time. */
+	    mc_account_unset_param (priv->account, "register");
+#endif
 	    mcd_presence_frame_set_account_status (priv->presence_frame,
 						   priv->account,
 						   conn_status, conn_reason);
