@@ -35,8 +35,9 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <libtelepathy/tp-connmgr.h>
-#include <libtelepathy/tp-interfaces.h>
+#include <telepathy-glib/dbus.h>
+#include <telepathy-glib/interfaces.h>
+#include <telepathy-glib/connection-manager.h>
 #include <libmissioncontrol/mission-control.h>
 
 #include "mcd-connection.h"
@@ -50,11 +51,11 @@ G_DEFINE_TYPE (McdManager, mcd_manager, MCD_TYPE_OPERATION);
 
 typedef struct _McdManagerPrivate
 {
-    DBusGConnection *dbus_connection;
+    TpDBusDaemon *dbus_daemon;
     McManager *mc_manager;
     McdPresenceFrame *presence_frame;
     McdDispatcher *dispatcher;
-    TpConnMgr *tp_conn_mgr;
+    TpConnectionManager *tp_conn_mgr;
     GList *accounts;
     gboolean is_disposed;
     gboolean delay_presence_request;
@@ -69,7 +70,7 @@ enum
     PROP_PRESENCE_FRAME,
     PROP_DISPATCHER,
     PROP_MC_MANAGER,
-    PROP_DBUS_CONNECTION,
+    PROP_DBUS_DAEMON,
     PROP_ACCOUNTS
 };
 
@@ -95,18 +96,27 @@ _mcd_manager_create_connection (McdManager * manager, McAccount * account)
     g_return_if_fail (mcd_manager_get_account_connection (manager, account) == NULL);
     if (!priv->tp_conn_mgr)
     {
+	GError *error = NULL;
+	const gchar *unique_name;
+
 	g_return_if_fail (MC_IS_MANAGER (priv->mc_manager));
 
+	unique_name = mc_manager_get_unique_name (priv->mc_manager);
 	priv->tp_conn_mgr =
-	    tp_connmgr_new (priv->dbus_connection,
-			    mc_manager_get_bus_name (priv->mc_manager),
-			    mc_manager_get_object_path (priv->mc_manager),
-			    TP_IFACE_CONN_MGR_INTERFACE);
-	g_debug ("%s: Manager %s created", G_STRFUNC,
-		 mc_manager_get_unique_name (priv->mc_manager));
+	    tp_connection_manager_new (priv->dbus_daemon, unique_name,
+				       mc_manager_get_filename (priv->mc_manager),
+				       &error);
+	if (error)
+	{
+	    g_warning ("%s, cannot create manager %s: %s", G_STRFUNC,
+		       unique_name, error->message);
+	    g_error_free (error);
+	    return;
+	}
+	g_debug ("%s: Manager %s created", G_STRFUNC, unique_name);
     }
     
-    connection = mcd_connection_new (priv->dbus_connection,
+    connection = mcd_connection_new (priv->dbus_daemon,
             mc_manager_get_bus_name (priv->
                 mc_manager),
             priv->tp_conn_mgr, account,
@@ -164,7 +174,7 @@ _find_connection (gconstpointer data, gconstpointer user_data)
 static gint
 _find_connection_by_path (gconstpointer data, gconstpointer user_data)
 {
-    TpConn *tp_conn;
+    TpConnection *tp_conn;
     McdConnection *connection = MCD_CONNECTION (data);
     const gchar *object_path = (const gchar *)user_data;
     const gchar *conn_object_path = NULL;
@@ -176,7 +186,7 @@ _find_connection_by_path (gconstpointer data, gconstpointer user_data)
 		  &tp_conn, NULL);
     if (!tp_conn)
 	return 1;
-    conn_object_path = dbus_g_proxy_get_path (DBUS_G_PROXY (tp_conn));
+    conn_object_path = TP_PROXY (tp_conn)->object_path;
     if (strcmp (conn_object_path, object_path) == 0)
     {
 	ret = 0;
@@ -278,7 +288,6 @@ abort_requested_channel (gchar *key, struct mcd_channel_request *req,
 			 "Connection cancelled");
     /* we must create a channel object, just for delivering the error */
     channel = mcd_channel_new (NULL,
-			       NULL,
 			       req->channel_type,
 			       0,
 			       req->channel_handle_type,
@@ -346,6 +355,7 @@ _mcd_manager_nuke_connections (McdManager *manager)
     DBusGProxy *proxy;
     GError *error = NULL;
     static gboolean already_nuked = FALSE;
+    DBusGConnection *dbus_connection;
     
     if (already_nuked)
 	return; /* We only nuke it once in process instance */
@@ -354,7 +364,8 @@ _mcd_manager_nuke_connections (McdManager *manager)
     g_debug ("Nuking possible stale connections");
     
     priv = MCD_MANAGER_PRIV (manager);
-    proxy = dbus_g_proxy_new_for_name(priv->dbus_connection,
+    dbus_connection = TP_PROXY (priv->dbus_daemon)->dbus_connection;
+    proxy = dbus_g_proxy_new_for_name(dbus_connection,
 				      DBUS_SERVICE_DBUS,
 				      DBUS_PATH_DBUS,
 				      DBUS_INTERFACE_DBUS);
@@ -385,9 +396,9 @@ _mcd_manager_nuke_connections (McdManager *manager)
 	    
 	    g_debug ("Trying to disconnect (%s), path=%s", *name, path);
 	    
-	    proxy = dbus_g_proxy_new_for_name(priv->dbus_connection,
+	    proxy = dbus_g_proxy_new_for_name(dbus_connection,
 					      *name, path,
-					      TP_IFACE_CONN_INTERFACE);
+					      TP_IFACE_CONNECTION);
 	    
 	    g_free(path);
 	    
@@ -529,12 +540,6 @@ _mcd_manager_dispose (GObject * object)
     
     _mcd_manager_set_presence_frame (MCD_MANAGER (object), NULL);
     
-    if (priv->dbus_connection)
-    {
-	dbus_g_connection_unref (priv->dbus_connection);
-	priv->dbus_connection = NULL;
-    }
-    
     if (priv->mc_manager)
     {
 	g_object_unref (priv->mc_manager);
@@ -546,7 +551,10 @@ _mcd_manager_dispose (GObject * object)
 	g_object_unref (priv->tp_conn_mgr);
 	priv->tp_conn_mgr = NULL;
     }
-    
+
+    if (priv->dbus_daemon)
+	g_object_unref (priv->dbus_daemon);
+
     G_OBJECT_CLASS (mcd_manager_parent_class)->dispose (object);
 }
 
@@ -595,7 +603,6 @@ _mcd_manager_set_property (GObject * obj, guint prop_id,
     McdPresenceFrame *presence_frame;
     McdDispatcher *dispatcher;
     McManager *mc_manager;
-    DBusGConnection *dbus_connection;
 
     switch (prop_id)
     {
@@ -624,12 +631,10 @@ _mcd_manager_set_property (GObject * obj, guint prop_id,
 	    g_object_unref (priv->mc_manager);
 	priv->mc_manager = mc_manager;
 	break;
-    case PROP_DBUS_CONNECTION:
-	dbus_connection = g_value_get_pointer (val);
-	dbus_g_connection_ref (dbus_connection);
-	if (priv->dbus_connection)
-	    dbus_g_connection_unref (priv->dbus_connection);
-	priv->dbus_connection = dbus_connection;
+    case PROP_DBUS_DAEMON:
+	if (priv->dbus_daemon)
+	    g_object_unref (priv->dbus_daemon);
+	priv->dbus_daemon = TP_DBUS_DAEMON (g_value_dup_object (val));
 	break;
     default:
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
@@ -654,8 +659,8 @@ _mcd_manager_get_property (GObject * obj, guint prop_id,
     case PROP_MC_MANAGER:
 	g_value_set_object (val, priv->mc_manager);
 	break;
-    case PROP_DBUS_CONNECTION:
-	g_value_set_pointer (val, priv->dbus_connection);
+    case PROP_DBUS_DAEMON:
+	g_value_set_object (val, priv->dbus_daemon);
 	break;
     case PROP_ACCOUNTS:
         g_debug ("%s: accounts getting over-written", G_STRFUNC);
@@ -731,13 +736,13 @@ mcd_manager_class_init (McdManagerClass * klass)
 							  MC_TYPE_MANAGER,
 							  G_PARAM_READWRITE |
 							  G_PARAM_CONSTRUCT_ONLY));
-    g_object_class_install_property (object_class, PROP_DBUS_CONNECTION,
-				     g_param_spec_pointer ("dbus-connection",
-							   _("DBus Connection"),
-							   _
-							   ("DBus connection to use by us"),
-							   G_PARAM_READWRITE |
-							   G_PARAM_CONSTRUCT));
+    g_object_class_install_property (object_class, PROP_DBUS_DAEMON,
+				     g_param_spec_object ("dbus-daemon",
+							  _("DBus daemon"),
+							  _("DBus daemon"),
+							  TP_TYPE_DBUS_DAEMON,
+							  G_PARAM_READWRITE |
+							  G_PARAM_CONSTRUCT));
     g_object_class_install_property (object_class, PROP_ACCOUNTS,
 				     g_param_spec_pointer ("accounts",
 							   _("Accounts"),
@@ -749,9 +754,6 @@ mcd_manager_class_init (McdManagerClass * klass)
 static void
 mcd_manager_init (McdManager * manager)
 {
-    McdManagerPrivate *priv = MCD_MANAGER_PRIV (manager);
-
-    priv->dbus_connection = NULL;
 }
 
 /* Public methods */
@@ -760,14 +762,14 @@ McdManager *
 mcd_manager_new (McManager * mc_manager,
 		 McdPresenceFrame * pframe,
 		 McdDispatcher *dispatcher,
-		 DBusGConnection * dbus_connection)
+		 TpDBusDaemon *dbus_daemon)
 {
     McdManager *obj;
     obj = MCD_MANAGER (g_object_new (MCD_TYPE_MANAGER,
 				     "mc-manager", mc_manager,
 				     "presence-frame", pframe,
 				     "dispatcher", dispatcher,
-				     "dbus-connection", dbus_connection, NULL));
+				     "dbus-daemon", dbus_daemon, NULL));
     _mcd_manager_nuke_connections (obj);
     return obj;
 }
@@ -1016,7 +1018,7 @@ mcd_manager_request_channel (McdManager *manager,
 	return FALSE;
     }
     else if (mcd_connection_get_connection_status (connection) !=
-	     TP_CONN_STATUS_CONNECTED)
+	     TP_CONNECTION_STATUS_CONNECTED)
     {
 	g_debug ("%s: connection is not connected", G_STRFUNC);
 	request_channel_delayed (manager, req);
