@@ -50,10 +50,10 @@
 /* VOID:UINT,UINT,UINT,STRING (mcd-signals-marshal.list:1) */
 void
 mcd_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closure,
-                                         GValue       *return_value,
+                                         GValue       *return_value G_GNUC_UNUSED,
                                          guint         n_param_values,
                                          const GValue *param_values,
-                                         gpointer      invocation_hint,
+                                         gpointer      invocation_hint G_GNUC_UNUSED,
                                          gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT_UINT_STRING) (gpointer     data1,
@@ -91,10 +91,10 @@ mcd_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closure,
 /* VOID:UINT,STRING,UINT (mcd-signals-marshal.list:2) */
 void
 mcd_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
-                                    GValue       *return_value,
+                                    GValue       *return_value G_GNUC_UNUSED,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_STRING_UINT) (gpointer     data1,
@@ -130,10 +130,10 @@ mcd_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
 /* VOID:STRING,UINT (mcd-signals-marshal.list:3) */
 void
 mcd_marshal_VOID__STRING_UINT (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_UINT) (gpointer     data1,
@@ -169,10 +169,10 @@ mcd_marshal_VOID__STRING_UINT (GClosure     *closure,
 /* VOID:UINT,UINT (mcd-signals-marshal.list:5) */
 void
 mcd_marshal_VOID__UINT_UINT (GClosure     *closure,
-                             GValue       *return_value,
+                             GValue       *return_value G_GNUC_UNUSED,
                              guint         n_param_values,
                              const GValue *param_values,
-                             gpointer      invocation_hint,
+                             gpointer      invocation_hint G_GNUC_UNUSED,
                              gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
@@ -206,10 +206,10 @@ mcd_marshal_VOID__UINT_UINT (GClosure     *closure,
 /* VOID:OBJECT,ENUM,STRING (mcd-signals-marshal.list:6) */
 void
 mcd_marshal_VOID__OBJECT_ENUM_STRING (GClosure     *closure,
-                                      GValue       *return_value,
+                                      GValue       *return_value G_GNUC_UNUSED,
                                       guint         n_param_values,
                                       const GValue *param_values,
-                                      gpointer      invocation_hint,
+                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_ENUM_STRING) (gpointer     data1,
@@ -245,10 +245,10 @@ mcd_marshal_VOID__OBJECT_ENUM_STRING (GClosure     *closure,
 /* VOID:ENUM,STRING (mcd-signals-marshal.list:7) */
 void
 mcd_marshal_VOID__ENUM_STRING (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ENUM_STRING) (gpointer     data1,
@@ -282,10 +282,10 @@ mcd_marshal_VOID__ENUM_STRING (GClosure     *closure,
 /* VOID:OBJECT,ENUM,ENUM (mcd-signals-marshal.list:8) */
 void
 mcd_marshal_VOID__OBJECT_ENUM_ENUM (GClosure     *closure,
-                                    GValue       *return_value,
+                                    GValue       *return_value G_GNUC_UNUSED,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_ENUM_ENUM) (gpointer     data1,
@@ -321,10 +321,10 @@ mcd_marshal_VOID__OBJECT_ENUM_ENUM (GClosure     *closure,
 /* VOID:INT,STRING (mcd-signals-marshal.list:9) */
 void
 mcd_marshal_VOID__INT_STRING (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_STRING) (gpointer     data1,
@@ -360,10 +360,10 @@ mcd_marshal_VOID__INT_STRING (GClosure     *closure,
 /* VOID:OBJECT,INT,STRING (mcd-signals-marshal.list:11) */
 void
 mcd_marshal_VOID__OBJECT_INT_STRING (GClosure     *closure,
-                                     GValue       *return_value,
+                                     GValue       *return_value G_GNUC_UNUSED,
                                      guint         n_param_values,
                                      const GValue *param_values,
-                                     gpointer      invocation_hint,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_INT_STRING) (gpointer     data1,
@@ -399,10 +399,10 @@ mcd_marshal_VOID__OBJECT_INT_STRING (GClosure     *closure,
 /* VOID:OBJECT,INT,INT (mcd-signals-marshal.list:12) */
 void
 mcd_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_INT_INT) (gpointer     data1,
@@ -440,10 +440,10 @@ mcd_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
 /* VOID:OBJECT,POINTER (mcd-signals-marshal.list:14) */
 void
 mcd_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_POINTER) (gpointer     data1,
@@ -479,10 +479,10 @@ mcd_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
 /* VOID:UINT,BOOLEAN (mcd-signals-marshal.list:16) */
 void
 mcd_marshal_VOID__UINT_BOOLEAN (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_BOOLEAN) (gpointer     data1,
